rulebase.rules package
======================

Subpackages
-----------

.. toctree::

    rulebase.rules.interval_based_operations
    rulebase.rules.sentence_segmentation

Module contents
---------------

.. automodule:: rulebase.rules
    :members:
    :undoc-members:
    :show-inheritance:
